/* eslint-disable react/destructuring-assignment */ 'use client';
import { getTranslation } from '@payloadcms/translations';
import React, { useCallback } from 'react';
import { useField } from '../../forms/useField/index.js';
import { withCondition } from '../../forms/withCondition/index.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { fieldBaseClass } from '../shared/index.js';
const baseClass = 'point';
import { FieldDescription } from '@payloadcms/ui/forms/FieldDescription';
import { FieldError } from '@payloadcms/ui/forms/FieldError';
import { FieldLabel } from '@payloadcms/ui/forms/FieldLabel';
import { useFieldProps } from '@payloadcms/ui/forms/FieldPropsProvider';
const PointField = (props)=>{
    const { name, AfterInput, BeforeInput, CustomDescription, CustomError, CustomLabel, className, descriptionProps, errorProps, labelProps, path: pathFromProps, placeholder, readOnly: readOnlyFromProps, required, step, style, validate, width } = props;
    const { i18n, t } = useTranslation();
    const memoizedValidate = useCallback((value, options)=>{
        if (typeof validate === 'function') {
            return validate(value, {
                ...options,
                required
            });
        }
    }, [
        validate,
        required
    ]);
    const { path: pathFromContext, readOnly: readOnlyFromContext } = useFieldProps();
    const readOnly = readOnlyFromProps || readOnlyFromContext;
    const { path, setValue, showError, value = [
        null,
        null
    ] } = useField({
        path: pathFromContext || pathFromProps || name,
        validate: memoizedValidate
    });
    const handleChange = useCallback((e, index)=>{
        let val = parseFloat(e.target.value);
        if (Number.isNaN(val)) {
            val = e.target.value;
        }
        const coordinates = [
            ...value
        ];
        coordinates[index] = val;
        setValue(coordinates);
    }, [
        setValue,
        value
    ]);
    const getCoordinateFieldLabel = (type)=>{
        const suffix = type === 'longitude' ? t('fields:longitude') : t('fields:latitude');
        const fieldLabel = labelProps && labelProps.label ? getTranslation(labelProps.label, i18n) : '';
        return {
            ...labelProps,
            label: `${fieldLabel}${fieldLabel ? ' - ' : ''}${suffix}`
        };
    };
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            baseClass,
            className,
            showError && 'error',
            readOnly && 'read-only'
        ].filter(Boolean).join(' '),
        style: {
            ...style,
            width
        }
    }, /*#__PURE__*/ React.createElement(FieldError, {
        CustomError: CustomError,
        path: path,
        ...errorProps || {}
    }), /*#__PURE__*/ React.createElement("ul", {
        className: `${baseClass}__wrap`
    }, /*#__PURE__*/ React.createElement("li", null, CustomLabel !== undefined ? CustomLabel : /*#__PURE__*/ React.createElement(FieldLabel, getCoordinateFieldLabel('longitude')), /*#__PURE__*/ React.createElement("div", {
        className: "input-wrapper"
    }, BeforeInput, /*#__PURE__*/ React.createElement("input", {
        disabled: readOnly,
        id: `field-longitude-${path.replace(/\./g, '__')}`,
        name: `${path}.longitude`,
        onChange: (e)=>handleChange(e, 0),
        placeholder: getTranslation(placeholder, i18n),
        step: step,
        type: "number",
        value: value && typeof value[0] === 'number' ? value[0] : ''
    }), AfterInput)), /*#__PURE__*/ React.createElement("li", null, CustomLabel !== undefined ? CustomLabel : /*#__PURE__*/ React.createElement(FieldLabel, getCoordinateFieldLabel('latitude')), /*#__PURE__*/ React.createElement("div", {
        className: "input-wrapper"
    }, BeforeInput, /*#__PURE__*/ React.createElement("input", {
        disabled: readOnly,
        id: `field-latitude-${path.replace(/\./g, '__')}`,
        name: `${path}.latitude`,
        onChange: (e)=>handleChange(e, 1),
        placeholder: getTranslation(placeholder, i18n),
        step: step,
        type: "number",
        value: value && typeof value[1] === 'number' ? value[1] : ''
    }), AfterInput))), CustomDescription !== undefined ? CustomDescription : /*#__PURE__*/ React.createElement(FieldDescription, descriptionProps || {}));
};
export const Point = withCondition(PointField);

//# sourceMappingURL=index.js.map