import { ViewDescription } from '@payloadcms/ui/elements/ViewDescription';
import { isPlainFunction, isReactComponent } from 'payload/utilities';
import React from 'react';
import { mapActions } from './actions.js';
import { mapFields } from './fields.js';
export const mapCollections = ({ DefaultEditView, DefaultListView, collections, config, readOnly: readOnlyOverride })=>collections.reduce((acc, collectionConfig)=>{
        const { slug, fields } = collectionConfig;
        const internalCollections = [
            'payload-preferences',
            'payload-migrations'
        ];
        if (internalCollections.includes(slug)) {
            return acc;
        }
        const editViewFromConfig = collectionConfig?.admin?.components?.views?.Edit;
        const listViewFromConfig = collectionConfig?.admin?.components?.views?.List;
        const CustomEditView = typeof editViewFromConfig === 'function' ? editViewFromConfig : typeof editViewFromConfig === 'object' && typeof editViewFromConfig.Default === 'function' ? editViewFromConfig.Default : typeof editViewFromConfig?.Default === 'object' && 'Component' in editViewFromConfig.Default && typeof editViewFromConfig.Default.Component === 'function' ? editViewFromConfig.Default.Component : undefined;
        const CustomListView = typeof listViewFromConfig === 'function' ? listViewFromConfig : typeof listViewFromConfig === 'object' && typeof listViewFromConfig.Component === 'function' ? listViewFromConfig.Component : undefined;
        const Edit = CustomEditView || DefaultEditView;
        const List = CustomListView || DefaultListView;
        const beforeList = collectionConfig?.admin?.components?.BeforeList;
        const beforeListTable = collectionConfig?.admin?.components?.BeforeListTable;
        const afterList = collectionConfig?.admin?.components?.AfterList;
        const afterListTable = collectionConfig?.admin?.components?.AfterListTable;
        const SaveButtonComponent = collectionConfig?.admin?.components?.edit?.SaveButton;
        const SaveButton = SaveButtonComponent ? /*#__PURE__*/ React.createElement(SaveButtonComponent, null) : undefined;
        const SaveDraftButtonComponent = collectionConfig?.admin?.components?.edit?.SaveDraftButton;
        const SaveDraftButton = SaveDraftButtonComponent ? /*#__PURE__*/ React.createElement(SaveDraftButtonComponent, null) : undefined;
        const PreviewButtonComponent = collectionConfig?.admin?.components?.edit?.PreviewButton;
        const PreviewButton = PreviewButtonComponent ? /*#__PURE__*/ React.createElement(PreviewButtonComponent, null) : undefined;
        const PublishButtonComponent = collectionConfig?.admin?.components?.edit?.PublishButton;
        const PublishButton = PublishButtonComponent ? /*#__PURE__*/ React.createElement(PublishButtonComponent, null) : undefined;
        const BeforeList = beforeList && Array.isArray(beforeList) && beforeList?.map((Component)=>/*#__PURE__*/ React.createElement(Component, null)) || null;
        const BeforeListTable = beforeListTable && Array.isArray(beforeListTable) && beforeListTable?.map((Component)=>/*#__PURE__*/ React.createElement(Component, null)) || null;
        const AfterList = afterList && Array.isArray(afterList) && afterList?.map((Component)=>/*#__PURE__*/ React.createElement(Component, null)) || null;
        const AfterListTable = afterListTable && Array.isArray(afterListTable) && afterListTable?.map((Component)=>/*#__PURE__*/ React.createElement(Component, null)) || null;
        const descriptionProps = {
            description: collectionConfig.admin && 'description' in collectionConfig.admin && ((typeof collectionConfig.admin?.description === 'string' || typeof collectionConfig.admin?.description === 'object') && collectionConfig.admin.description || typeof collectionConfig.admin?.description === 'function' && isPlainFunction(collectionConfig.admin?.description) && collectionConfig.admin?.description()) || undefined
        };
        const DescriptionComponent = collectionConfig.admin && 'description' in collectionConfig.admin && (isReactComponent(collectionConfig.admin.description) && collectionConfig.admin.description || collectionConfig.admin.description && ViewDescription) || undefined;
        const Description = DescriptionComponent !== undefined ? /*#__PURE__*/ React.createElement(DescriptionComponent, descriptionProps || {}) : undefined;
        const componentMap = {
            AfterList,
            AfterListTable,
            BeforeList,
            BeforeListTable,
            Description,
            Edit: /*#__PURE__*/ React.createElement(Edit, {
                collectionSlug: collectionConfig.slug
            }),
            List: /*#__PURE__*/ React.createElement(List, {
                collectionSlug: collectionConfig.slug
            }),
            PreviewButton,
            PublishButton,
            SaveButton,
            SaveDraftButton,
            actionsMap: mapActions({
                collectionConfig
            }),
            fieldMap: mapFields({
                config,
                fieldSchema: fields,
                readOnly: readOnlyOverride
            }),
            isPreviewEnabled: !!collectionConfig?.admin?.preview
        };
        return {
            ...acc,
            [slug]: componentMap
        };
    }, {});

//# sourceMappingURL=collections.js.map