'use client';
import { t } from '@payloadcms/translations';
import React, { createContext, useContext } from 'react';
import { useRouteCache } from '../RouteCache/index.js';
const Context = /*#__PURE__*/ createContext({
    i18n: {
        fallbackLanguage: 'en',
        language: 'en',
        t: (key)=>key,
        translations: {}
    },
    languageOptions: undefined,
    switchLanguage: undefined,
    t: (key)=>key
});
export const TranslationProvider = ({ children, fallbackLang, lang, languageOptions, switchLanguageServerAction, translations })=>{
    const { clearRouteCache } = useRouteCache();
    const nextT = (key, vars)=>t({
            key,
            translations,
            vars
        });
    const switchLanguage = React.useCallback(async (lang)=>{
        try {
            await switchLanguageServerAction(lang);
            clearRouteCache();
        } catch (error) {
            // eslint-disable-next-line no-console
            console.error(`Error loading language: "${lang}"`, error);
        }
    }, [
        switchLanguageServerAction,
        clearRouteCache
    ]);
    return /*#__PURE__*/ React.createElement(Context.Provider, {
        value: {
            i18n: {
                fallbackLanguage: fallbackLang,
                language: lang,
                t: nextT,
                translations: {
                    [lang]: translations
                }
            },
            languageOptions,
            switchLanguage,
            t: nextT
        }
    }, children);
};
export const useTranslation = ()=>useContext(Context);

//# sourceMappingURL=index.js.map